/*
 *   Copyright [2008] [Anay Nayak]
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package com.googlecode.equalsnhashcode;

import com.googlecode.equalsnhashcode.utils.Lists;
import com.intellij.codeInspection.InspectionManager;
import com.intellij.codeInspection.LocalQuickFix;
import com.intellij.codeInspection.ProblemDescriptor;
import com.intellij.codeInspection.ProblemHighlightType;
import com.intellij.psi.PsiField;

import java.util.Collections;
import java.util.List;

public class EqualsHashcodeProblemDescriptor {
    private InspectionManager inspectionManager;
    private String message;

    public EqualsHashcodeProblemDescriptor(InspectionManager inspectionManager, String message) {
        this.inspectionManager = inspectionManager;
        this.message = message;
    }

    public List<ProblemDescriptor> problemDescriptorsFor(List<PsiField> psiFields) {
        if (psiFields.isEmpty())
            return Collections.emptyList();
        List<ProblemDescriptor> problemDescriptors = Lists.create();
        for (PsiField field : psiFields) {
            problemDescriptors.add(inspectionManager.createProblemDescriptor(field,
                    String.format(message, field.getName()), (LocalQuickFix) null, ProblemHighlightType.GENERIC_ERROR_OR_WARNING));
        }
        return problemDescriptors;
    }
}
