/*
 *   Copyright [2008] [Anay Nayak]
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package com.googlecode.equalsnhashcode.finders;

import com.intellij.psi.PsiClass;
import com.intellij.psi.PsiMethod;
import com.intellij.psi.PsiParameter;


public class EqualsMethodFinder {
    private PsiClass psiClass;
    private static final String EQUALS = "equals";

    public EqualsMethodFinder(PsiClass psiClass) {
        this.psiClass = psiClass;
    }

    public PsiMethod find() {
        PsiMethod[] psiMethods = psiClass.findMethodsByName(EQUALS, false);
        PsiMethod result = null;

        for (PsiMethod psiMethod : psiMethods) {
            if (psiMethod.getName().equals(EQUALS) && hasOneParameter(psiMethod) && parameterIsOfType(Object.class, psiMethod)) {
                return psiMethod;
            }
        }
        return result;
    }

    private boolean parameterIsOfType(Class objectClass, PsiMethod psiMethod) {
        return objectClass.getCanonicalName().equals(firstParameter(psiMethod).getTypeElement().getType().getCanonicalText());
    }

    private PsiParameter firstParameter(PsiMethod psiMethod) {
        return psiMethod.getParameterList().getParameters()[0];
    }

    private boolean hasOneParameter(PsiMethod psiMethod) {
        return psiMethod.getParameterList().getParametersCount() == 1;
    }

}

