/*
 *   Copyright [2008] [Anay Nayak]
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package com.googlecode.equalsnhashcode.utils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class Lists {

    public static <T> List<T> create(T... elements) {
        List<T> list = new ArrayList<T>();
        list.addAll(Arrays.<T>asList(elements));
        return list;
    }

    public static <T> List<T> concat(List<T> list1, List<T> list2) {
        List<T> allElements = Lists.create();
        allElements.addAll(list1);
        allElements.addAll(list2);
        return allElements;
    }

    public static <T> List<T> filter(List<T> elements, Constraint<T> constraint) {
        List<T> filteredElements = new ArrayList<T>();
        for (T element : elements) {
            if (constraint.isSatisfiedBy(element))
                filteredElements.add(element);
        }
        return filteredElements;
    }
}
